@@ -1,13 +1,14 @@
-from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 
+from giant_plugins.mixins import ExtendedPluginBase
+
 from . import models
 
 __all__ = ["HeroImagePlugin"]
 
 
 @plugin_pool.register_plugin
-class HeroImagePlugin(CMSPluginBase):
+class HeroImagePlugin(ExtendedPluginBase):
     """
     CMS plugin for the Image Hero model
     """
